@@ -7,7 +7,7 @@
 #' @author Jan Philipp Dietrich
 #' @seealso \code{\link{getMainfolder}}, \code{\link{getConfig}}, \code{\link{setConfig}}
 #'
-initializeConfig <- function(verbose=TRUE) {
+initializeConfig <- function(verbose = TRUE) {
   # check whether config has not been initialized yet
   # and initialize it (otherwise do nothing)
   if (is.null(getOption("madrat_cfg"))) {
@@ -18,25 +18,22 @@ initializeConfig <- function(verbose=TRUE) {
                 packages             = "madrat",
                 globalenv            = FALSE,
                 verbosity            = 1,
-                enablecache          = TRUE,
                 mainfolder           = getMainfolder(verbose = verbose),
                 sourcefolder         = NA,
                 cachefolder          = NA,
                 mappingfolder        = NA,
                 outputfolder         = NA,
-                pop_threshold        = 10^6,
+                pucfolder            = NA,
+                tmpfolder            = NA,
                 nolabels             = NULL,
                 forcecache           = FALSE,
                 ignorecache          = NULL,
                 cachecompression     = "gzip",
                 hash                 = "xxhash32",
-                delete_cache         = TRUE,
                 diagnostics          = FALSE,
-                nocores              = 1,
                 debug                = FALSE,
-                indentationCharacter = "~",
                 maxLengthLogMessage = 200)
-     options(madrat_cfg = cfg)
+     options(madrat_cfg = cfg) # nolint
      if (verbose) {
       message(paste(paste0("    ", names(cfg)), cfg, sep = " = ", collapse = "\n"))
       message("..done!\n")
