@@ -1,5 +1,3 @@
-context("findBottlenecks")
-
 log <- c('Run calcOutput("TauTotal", years = 1995, round = 2, file = "fm_tau1995.cs4")',
          '> Run readSource("Tau", source)',
          '> Exit readSource("Tau", source) in 5.15 seconds',
@@ -13,11 +11,14 @@ logBugged <- c('Run calcOutput("TauTotal", years = 1995, round = 2, file = "fm_t
                'Exit retrieveData("example", rev = 2) in 5.58 seconds')
 
 test_that("bottleneck detection worksy", {
-  expect_message({x <- findBottlenecks(log)}, "5 seconds")
-  expect_equal(nrow(x),3)
-  expect_equal(ncol(x),7)
+  expect_message({
+    x <- findBottlenecks(log)
+  }, "5 seconds")
+  expect_equal(nrow(x), 3)
+  expect_equal(ncol(x), 7)
   file <- tempfile()
-  writeLines(logBugged,file)
-  expect_warning({x <- findBottlenecks(file, unit="h")}, "could not be properly detected")
+  writeLines(logBugged, file)
+  expect_warning({
+    x <- findBottlenecks(file, unit = "h")
+  }, "could not be properly detected")
 })
-
